@@ -14,8 +14,6 @@ from ..core.tcp import serving, clienting
 from ..help import timing, helping
 
 
-
-
 class Doist(tyming.Tymist):
     """
     Doist is the root coroutine scheduler
@@ -91,7 +89,8 @@ class Doist(tyming.Tymist):
                 .done state to associated doer for dog
 
         Calls each generator callable (instance or function or method) in .doers
-        to create each generator dog.
+        to create each generator dog. Injects own tymth function closure, and
+            generator function's own tock, and opts.
 
         Runs enter context of each dog by calling next(dog)
 
@@ -109,12 +108,13 @@ class Doist(tyming.Tymist):
 
         deeds = deque()
         for index, doer in enumerate(self.doers):
-            if ismethod(doer):  # when using bound method for generator function
-                doer.__func__.done = None  # None before enter. enter may set to False
-            else:
+            try:
                 doer.done = None  #  None before enter. enter may set to False
+            except AttributeError:  # when using bound method for generator function
+                doer.__func__.done = None  # None before enter. enter may set to False
+
             opts = doer.opts if hasattr(doer, "opts") else {}
-            dog = doer(tymist=self, tock=doer.tock, **opts)
+            dog = doer(tymth=self.tymen(), tock=doer.tock, **opts)
             try:
                 next(dog)  # run enter by advancing to first yield
             except StopIteration:
@@ -142,7 +142,11 @@ class Doist(tyming.Tymist):
                 try:
                     tock = dog.send(self.tyme)  # send tyme. yield tock
                 except StopIteration as ex:  # returned instead of yielded
-                    self.doers[index].done = ex.value if ex.value else False  # assign done state
+                    doer = self.doers[index]
+                    try:
+                        doer.done = ex.value if ex.value else False  # assign done state
+                    except AttributeError:   # when using bound method for generator function
+                        doer.__func__.done = ex.value if ex.value else False  # assign done state
                 else:  # reappend for next pass
                     if tock is None:  # bare yield returns None
                         tock = 0.0  # rerun asap when tock == 0.0
@@ -184,7 +188,7 @@ class Doist(tyming.Tymist):
 
         deeds = self.ready(doers=doers)  # runs enter context on each doer
 
-        tymer = tyming.Tymer(tymist=self, duration=self.limit)
+        tymer = tyming.Tymer(tymth=self.tymen(), duration=self.limit)
         self.timer.start()
         try:  # always clean up resources upon exception
             while True:  # until doers complete or exception or keyboardInterrupt
@@ -243,10 +247,10 @@ class Doist(tyming.Tymist):
                 pass  # Hmm? Not supposed to happen!
             else:  # set done state
                 doer = self.doers[index]
-                if ismethod(doer):  # when using bound method for generator function
-                    doer.__func__.done = False  # forced close
-                else:
+                try:
                     doer.done = False  # forced close
+                except AttributeError:  # when using bound method for generator function
+                    doer.__func__.done = False  # forced close
 
 
 def doify(f, name=None, tock=0.0, **opts):
@@ -332,15 +336,18 @@ class Doer(tyming.Tymee):
         .opts is dict of injected options into its .do generator by scheduler
 
     Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
+        .tyme is float relative cycle time of associated Tymist .tyme obtained
+            via injected .tymth function wrapper closure.
+        .tymth is function wrapper closure returned by Tymist .tymeth() method.
+            When .tymth is called it returns associated Tymist .tyme.
+            .tymth provides injected dependency on Tymist tyme base.
 
     Properties:
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
     Inherited Methods:
-        .wind  injects ._tymist dependency
+        .wind  injects ._tymth dependency from associated Tymist to get its .tyme
 
     Methods:
         .__call__ makes instance callable
@@ -354,8 +361,9 @@ class Doer(tyming.Tymee):
         .abort is abort context method
 
     Hidden:
-       ._tymist is Tymist instance reference
-       ._tock is hidden attribute for .tock property
+        ._tymth is injected function wrapper closure returned by .tymen() of
+            associated Tymist instance that returns Tymist .tyme. when called.
+        ._tock is hidden attribute for .tock property
 
     """
 
@@ -364,7 +372,8 @@ class Doer(tyming.Tymee):
         Initialize instance.
 
         Inherited Parameters:
-            tymist is  Tymist instance
+            tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
 
         Parameters:
            tock is float seconds initial value of .tock
@@ -406,7 +415,7 @@ class Doer(tyming.Tymee):
         self._tock = abs(float(tock))
 
 
-    def do(self, tymist=None, tock=0.0, **opts):
+    def do(self, tymth, tock=0.0, **opts):
         """
         Generator method to run this doer.
         Calling this method returns generator.
@@ -415,21 +424,21 @@ class Doer(tyming.Tymee):
             .enter, .recur, .exit, .close, .abort
 
         Parameters:
-            tymist is injected Tymist instance with tymist.tyme
+            tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
             tock is injected initial tock value
             args is dict of injected optional additional parameters
         """
         try:
             # enter context
-            self.wind(tymist)  # change tymist and dependencies
+            self.wind(tymth)  # update tymist dependencies
             self.tock = tock  #  set tock to parameter
-            tyme = self.tyme
             self.done = False  # allows enter to override completion state
             self.enter()
 
             #recur context
             if isgeneratorfunction(self.recur):  #  .recur is generator method
-                self.done = yield from self.recur(tyme)  # recur context
+                self.done = yield from self.recur()  # recur context delegated
             else:  # .recur is standard method so iterate in while loop
                 while (not self.done):  # recur context
                     tyme = (yield (self.tock))  # yields .tock then waits for next send
@@ -532,13 +541,16 @@ class ReDoer(Doer):
         .opts is dict of injected options into its .do generator by scheduler
 
     Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
+         .tyme is float relative cycle time of associated Tymist .tyme obtained
+            via injected .tymth function wrapper closure.
+        .tymth is function wrapper closure returned by Tymist .tymeth() method.
+            When .tymth is called it returns associated Tymist .tyme.
+            .tymth provides injected dependency on Tymist tyme base.
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
     Inherited Methods:
-        .wind  injects ._tymist dependency
+        .wind  injects ._tymth dependency from associated Tymist to get its .tyme
         .__call__ makes instance callable
             Appears as generator function that returns generator
         .do is generator method that returns generator
@@ -552,12 +564,13 @@ class ReDoer(Doer):
         .recur
 
     Hidden:
-       ._tymist is Tymist instance reference
+       ._tymth is injected function wrapper closure returned by .tymen() of
+            associated Tymist instance that returns Tymist .tyme. when called.
        ._tock is hidden attribute for .tock property
 
     """
 
-    def recur(self, tyme):
+    def recur(self):
         """
         Do 'recur' context actions as a generator method. Override in subclass.
         Assumes resource setup in .enter() and resource takedown in .exit()
@@ -595,7 +608,8 @@ class DoDoer(Doer):
     """
     DoDoer implements Doist like functionality to allow nested scheduling of Doers.
     Each DoDoer runs a list of doers like a Doist but using the tyme from its
-       injected tymist as injected by its parent DoDoer or Doist.
+       injected tymth for the associated tymist as injected by its ultimate root
+       parent Doist and any intervening parent DoDoer(s).
 
     Scheduling hierarchy: Doist->DoDoer...->DoDoer->Doers
 
@@ -606,15 +620,20 @@ class DoDoer(Doer):
         .opts is dict of injected options for its generator .do
 
     Attributes:
-        .doers is list of Doers or Doer like generator functions
+
 
     Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
+        .tyme is float relative cycle time of associated Tymist .tyme obtained
+            via injected .tymth function wrapper closure.
+        .tymth is function wrapper closure returned by Tymist .tymeth() method.
+            When .tymth is called it returns associated Tymist .tyme.
+            .tymth provides injected dependency on Tymist tyme base.
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
     Properties:
+        .doers is list of Doers or Doist compatible generator instances,
+            functions, or methods.
         .deeds is deque of triples (dog, retyme, index)  where:
             dog is generator
             retyme is tyme in seconds when next should run may be real or simulated
@@ -624,7 +643,7 @@ class DoDoer(Doer):
             doers and associated deeds while running.
 
     Inherited Methods:
-        .wind  injects ._tymist dependency
+        .wind  injects ._tymth dependency from associated Tymist to get its .tyme
         .__call__ makes instance callable
             Appears as generator function that returns generator
         .do is generator method that returns generator
@@ -642,22 +661,26 @@ class DoDoer(Doer):
         .exit
 
     Hidden:
-       ._tymist is Tymist instance reference
+       ._tymth is injected function wrapper closure returned by .tymen() of
+            associated Tymist instance that returns Tymist .tyme. when called.
        ._tock is hidden attribute for .tock property
        ._always is hidden attribute for .always propery
 
     """
 
-    def __init__(self, doers=None, always=False, **kwa):
+    def __init__(self, doers=None, deeds=None, always=False, **kwa):
         """
         Initialize instance.
 
         Inherited Parameters:
-            tymist is  Tymist instance
+            tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
             tock is float seconds initial value of .tock
 
         Parameters:
-           doers is list of doer compatible generator functions
+           doers is list of doist compatible generator instances, functions, or
+               methods
+           deeds is deque to hold deeds
            always is Boolean, True means keep running even when all dogs in deeds
             are complete. Enables dynamically managing extending or removing
             doers and associated deeds while running.
@@ -665,8 +688,28 @@ class DoDoer(Doer):
         """
         super(DoDoer, self).__init__(**kwa)
         self.doers = doers if doers is not None else []
+        self.deeds = deeds if deeds is not None else deque()
         self.always = always
-        self.deeds = deque()
+
+
+    @property
+    def doers(self):
+        """
+        doers property getter, get ._doers
+        .doers is list of doist compatible generator instances, functions, or
+            methods
+        """
+        return self._doers
+
+
+    @doers.setter
+    def doers(self, doers):
+        """
+        set ._doers to doers list
+        """
+        if not isinstance(doers, list):
+            raise TypeError("Expected list, got {}.".format(type(doers)))
+        self._doers = doers
 
 
     @property
@@ -707,15 +750,15 @@ class DoDoer(Doer):
         self._always = True if always else False
 
 
-    def do(self, tymist=None, tock=0.0, doers=None, always=None, **opts):
+    def do(self, tymth, tock=0.0, doers=None, deeds=None, always=None, **opts):
         """
         Generator method to run this doer. Equivalent of doist.do
         Calling this method returns generator
         Interface matched generator function for compatibility
 
         Parameters:
-            tymist is injected Tymist instance with tymist.tyme. So tymist
-                same as doist or dodoer that is doing this dodoer.
+            tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
             tock is injected initial tock value
             opts is dict of injected optional additional parameters
             doers is list of doers (generator functions)
@@ -727,18 +770,21 @@ class DoDoer(Doer):
         always = always if always is not None else self.always
         if doers is not None:
             self.doers = doers
+        if deeds is not None:
+            self.deeds = deeds
+
         try:
             # enter context
-            self.wind(tymist)  # change tymist and dependencies
+            self.wind(tymth)  # change tymist dependencies
             self.tock = tock  #  set tock to parameter
             # tyme = self.tyme
             self.done = False  # allows enter to override completion state
-            self.deeds = self.enter(doers=self.doers)  # doist.ready equivalent
+            self.enter()  # doist.ready equivalent
 
             #recur context
             while (not self.done or always):  # recur context
                 tyme = (yield (self.tock))  # yields .tock then waits for next send
-                self.done = self.recur(tyme=tyme, deeds=self.deeds)  # equv of doist.once
+                self.done = self.recur(tyme=tyme)  # equv of doist.once
 
         except GeneratorExit:  # close context, forced exit due to .close
             self.close()
@@ -751,7 +797,7 @@ class DoDoer(Doer):
             self.clean()
 
         finally:  # exit context, exit, unforced if normal exit of try, forced otherwise
-            self.exit(deeds=self.deeds, doers=self.doers)  # equiv of doist.do finally clause
+            self.exit()  # equiv of doist.do finally clause
 
         # return value of yield from or StopIteration.value indicates completion
         return self.done  # Only returns done state if normal return not close or abort raise
@@ -786,12 +832,12 @@ class DoDoer(Doer):
             deeds = self.deeds
 
         for index, doer in enumerate(doers):
-            if ismethod(doer):  # when using bound method for generator function
-                doer.__func__.done = None  # None before enter. enter may set to False
-            else:
+            try:
                 doer.done = None  # None before enter. enter may set to False
+            except AttributeError:   # when using bound method for generator function
+                doer.__func__.done = None  # None before enter. enter may set to False
             opts = doer.opts if hasattr(doer, "opts") else {}
-            dog = doer(tymist=self._tymist, tock=doer.tock, **opts)
+            dog = doer(tymth=self.tymth, tock=doer.tock, **opts)
             try:
                 next(dog)  # run enter by advancing to first yield
             except StopIteration:
@@ -800,7 +846,7 @@ class DoDoer(Doer):
         return deeds
 
 
-    def recur(self, tyme, deeds=None):
+    def recur(self, tyme, doers=None, deeds=None):
         """
         Do 'recur' context actions. Equivalent of Doist.once
 
@@ -820,6 +866,8 @@ class DoDoer(Doer):
 
         Each cycle checks all generators dogs in deeds deque and runs if retyme past.
         """
+        if doers is None:
+            doers = self.doers
         if deeds is None:
             deeds = self.deeds
 
@@ -830,7 +878,11 @@ class DoDoer(Doer):
                 try:  # tock == 0.0 means re-run asap
                     tock = dog.send(tyme)  # send tyme. yield tock
                 except StopIteration as ex:  # returned instead of yielded
-                    self.doers[index].done = ex.value if ex.value else False  # assign done state
+                    doer = doers[index]
+                    try:
+                        doer.done = ex.value if ex.value else False  # assign done state
+                    except AttributeError:
+                        doer.__func__.done = ex.value if ex.value else False  # assign done state
                 else:  # reappend for next pass
                     if tock is None:  # bare yield results None
                         tock = 0.0  # # rerun asap when tock == 0.0
@@ -841,7 +893,7 @@ class DoDoer(Doer):
         return (not deeds)  # True if deeds deque is empty
 
 
-    def exit(self, deeds=None, doers=None):
+    def exit(self, doers=None, deeds=None, ):
         """
         Do 'exit' context actions.
 
@@ -866,10 +918,10 @@ class DoDoer(Doer):
                 pass  # Hmm? Not supposed to happen!
             else:  # set done state
                 doer = doers[index]
-                if ismethod(doer):  # when using bound method for generator function
-                    doer.__func__.done = False  # forced close
-                else:
+                try:
                     doer.done = False  # forced close
+                except AttributeError:  # when using bound method for generator function
+                    doer.__func__.done = False  # forced close
 
 
     def extend(self, doers):
@@ -913,7 +965,6 @@ class DoDoer(Doer):
                 indices[i] = j
                 j += 1
 
-
         rdeeds = deque()  # fresh deque for deeds to remove
         deeds = self.deeds  # edit update self.deeds in place
         for i in range(len(deeds)):  # iterate once over each deed
@@ -926,73 +977,42 @@ class DoDoer(Doer):
         for doer in rdoers:  # update .doers to remove rdoers
             self.doers.remove(doer)
 
-        self.exit(deeds=rdeeds, doers=rdoers)
-
-
-
-
-
+        self.exit(doers=rdoers, deeds=rdeeds)
 
 
 class ServerDoer(Doer):
     """
     Basic TCP Server
 
-    Inherited Attributes:
-        .done is Boolean completion state:
-            True means completed
-            Otherwise incomplete. Incompletion maybe due to close or abort.
-        .opts is dict of injected options into its .do generator by scheduler
+    See Doer for inherited attributes, properties, and methods.
 
     Attributes:
        .server is TCP Server instance
 
-    Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
-        .tock is float, desired time in seconds between runs or until next run,
-                 non negative, zero means run asap
-
     Properties:
 
-    Methods:
-        .wind  injects ._tymist dependency
-        .__call__ makes instance callable
-            Appears as generator function that returns generator
-        .do is generator method that returns generator
-        .enter is enter context action method
-        .recur is recur context action method or generator method
-        .exit is exit context method
-        .close is close context method
-        .abort is abort context method
-
-    Hidden:
-       ._tymist is Tymist instance reference
-       ._tock is hidden attribute for .tock property
     """
 
     def __init__(self, server, **kwa):
         """
-        Inherited Parameters:
-           tymist is Tymist instance
-           tock is float seconds initial value of .tock
+        Initialize
 
         Parameters:
            server is TCP Server instance
         """
         super(ServerDoer, self).__init__(**kwa)
-        server.tymist = self._tymist
         self.server = server
+        if self.tymth:
+            self.server.wind(self.tymth)
 
 
-    def wind(self, tymist):
+    def wind(self, tymth):
         """
-        Inject new ._tymist and any other bundled tymee references
-        Update any dependencies on a change in ._tymist:
-            starts over itself at new ._tymists time
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
         """
-        super(ServerDoer, self).wind(tymist)
-        self.server.tymist = self._tymist
+        super(ServerDoer, self).wind(tymth)
+        self.server.wind(tymth)
 
 
     def enter(self):
@@ -1015,21 +1035,11 @@ class EchoServerDoer(ServerDoer):
     Echo TCP Server
     Just echoes back to client whatever it receives from client
 
+    See Doer for inherited attributes, properties, and methods.
+
     Inherited Attributes:
         .server is TCP Server instance
 
-    Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
-        .tock is float, desired time in seconds between runs or until next run,
-                 non negative, zero means run asap
-
-    Inherited Methods:
-        .__call__ makes instance callable return generator
-        .do is generator function returns generator
-
-    Hidden:
-       ._tock is hidden attribute for .tock property
 
     """
 
@@ -1056,18 +1066,7 @@ class ClientDoer(Doer):
     """
     Basic TCP Client
 
-    Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
-        .tock is float, desired time in seconds between runs or until next run,
-                 non negative, zero means run asap
-
-    Inherited Methods:
-        .__call__ makes instance callable return generator
-        .do is generator function returns generator
-
-    Hidden:
-       ._tock is hidden attribute for .tock property
+    See Doer for inherited attributes, properties, and methods.
 
     Attributes:
        .client is TCP Client instance
@@ -1077,26 +1076,23 @@ class ClientDoer(Doer):
     def __init__(self, client, **kwa):
         """
         Initialize instance.
-        Inherited Parameters:
-           tymist is Tymist instance
-           tock is float seconds initial value of .tock
 
         Parameters:
            client is TCP Client instance
         """
         super(ClientDoer, self).__init__(**kwa)
-        client.tymist = self._tymist
         self.client = client
+        if self.tymth:
+            self.client.wind(self.tymth)
 
 
-    def wind(self, tymist):
+    def wind(self, tymth):
         """
-        Inject new ._tymist and any other bundled tymee references
-        Update any dependencies on a change in ._tymist:
-            starts over itself at new ._tymists time
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
         """
-        super(ClientDoer, self).wind(tymist)
-        self.client.tymist = self._tymist
+        super(ClientDoer, self).wind(tymth)
+        self.client.wind(tymth)
 
 
     def enter(self):
@@ -1120,18 +1116,7 @@ class EchoConsoleDoer(Doer):
 
     To test in WingIde must configure Debug i/O to use external console
 
-    Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
-        .tock is float, desired time in seconds between runs or until next run,
-                 non negative, zero means run asap
-
-    Inherited Methods:
-        .__call__ makes instance callable return generator
-        .do is generator function returns generator
-
-    Hidden:
-       ._tock is hidden attribute for .tock property
+    See Doer for inherited attributes, properties, and methods.
 
     Attributes:
        .console is serial Console instance
@@ -1141,9 +1126,6 @@ class EchoConsoleDoer(Doer):
     def __init__(self, console, lines=None, txbs=None, **kwa):
         """
         Initialize instance.
-        Inherited Parameters:
-           tymist is Tymist instance
-           tock is float seconds initial value of .tock
 
         Parameters:
            console is serial Console instance
@@ -1204,7 +1186,7 @@ class EchoConsoleDoer(Doer):
         self.console.close()
 
 
-def bareDo(tymist=None, tock=0.0, **opts):
+def bareDo(tymth=None, tock=0.0, **opts):
     """
     Bare bones generator function template as example of generator function
     suitable for use with either doify wrapper or doize decorator.
@@ -1222,7 +1204,8 @@ def bareDo(tymist=None, tock=0.0, **opts):
         g.opts
 
     Parameters:
-        tymist is injected Tymist instance with tymist.tyme
+        tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
         tock is injected initial tock value
         opts is dict of injected optional additional parameters
 
@@ -1236,7 +1219,7 @@ def bareDo(tymist=None, tock=0.0, **opts):
     """
     try:
         # enter context
-        tyme = tymist.tyme
+        # tyme = tymth()
         done = False
 
         while not done:  # recur context
@@ -1265,45 +1248,17 @@ class ExDoer(Doer):
     ExDoer is example Doer for testing and demonstration
     Supports introspection with methods to record sends and yields
 
-    Inherited Attributes:
-        .done is Boolean completion state:
-            True means completed
-            Otherwise incomplete. Incompletion maybe due to close or abort.
-        .opts is dict of injected options into its .do generator by scheduler
+    See Doer for inherited attributes, properties, and methods.
 
     Attributes:
        .states is list of State namedtuples (tyme, context, feed, count)
        .count is iteration count
 
-    Inherited Properties:
-        .tyme is float ._tymist.tyme, relative cycle or artificial time
-        .tymist is Tymist instance
-        .tock is float, desired time in seconds between runs or until next run,
-                 non negative, zero means run asap
-
-    Methods:
-        .wind  injects ._tymist dependency
-        .__call__ makes instance callable
-            Appears as generator function that returns generator
-        .do is generator method that returns generator
-        .enter is enter context action method
-        .recur is recur context action method or generator method
-        .exit is exit context method
-        .close is close context method
-        .abort is abort context method
-
-    Hidden:
-       ._tymist is Tymist instance reference
-       ._tock is hidden attribute for .tock property
     """
 
     def __init__(self, **kwa):
         """
         Initialize instance.
-        Parameters:
-           tymist is Tymist instance
-           tock is float seconds initial value of .tock
-
         """
         super(ExDoer, self).__init__(**kwa)
         self.states = []
@@ -1346,75 +1301,90 @@ class ExDoer(Doer):
 
 
 
-def doifyExDo(tymist=None, tock=0.0, states=None, **opts):
+def doifyExDo(tymth, tock=0.0, states=None, **opts):
     """
     Example generator function for testing and demonstration.
     Example non-class based generator for use with doify wrapper.
     Calling this function returns generator.
     Wrapping this function with doify returns copy with unique attributes
+
+    Parameters:
+        tymth is injected function wrapper closure returned by .tymen() of
+                Tymist instance. Calling tymth() returns associated Tymist .tyme.
+        tock is injected initial tock value
+        states is list of State namedtuples (tyme, context, feed, count)
+        opts is dict of injected optional additional parameters
+
     """
-    tyme = tymist.tyme
+    tyme = tymth()
     count = 0
     states = states if states is not None else []
 
     try:
         # enter context
-        states.append(State(tyme=tymist.tyme, context="enter", feed=tyme, count=count))
+        states.append(State(tyme=tymth(), context="enter", feed=tyme, count=count))
         while (True):  # recur context
             tyme = (yield (tock))  # yields tock then waits for next send
             count += 1
-            states.append(State(tyme=tymist.tyme, context="recur", feed=tyme, count=count))
+            states.append(State(tyme=tymth(), context="recur", feed=tyme, count=count))
             if count > 3:
                 break  # normal exit
 
     except GeneratorExit:  # close context, forced exit due to .close
         count += 1
-        states.append(State(tyme=tymist.tyme, context='close', feed=None, count=count))
+        states.append(State(tyme=tymth(), context='close', feed=None, count=count))
 
     except Exception as ex:  # abort context, forced exit due to uncaught exception
         count += 1
-        states.append(State(tyme=tymist.tyme, context='abort', feed=ex.args[0], count=count))
+        states.append(State(tyme=tymth(), context='abort', feed=ex.args[0], count=count))
         raise ex
 
     finally:  # exit context,  unforced exit due to normal exit of try
         count += 1
-        states.append(State(tyme=tymist.tyme, context='exit', feed=None, count=count))
+        states.append(State(tyme=tymth(), context='exit', feed=None, count=count))
 
     return (True)  # return value of yield from, or yield ex.value of StopIteration
 
 
 @doize(tock=0, states=None)
-def doizeExDo(tymist=None, tock=0.0, states=None, **opts):
+def doizeExDo(tymth, tock=0.0, states=None, **opts):
     """
     Example decorated generator function for use with doize decorator.
     Example non-class based generator
     Calling this function returns generator
+
+    Parameters:
+        tymth is injected function wrapper closure returned by .tymen() of
+            Tymist instance. Calling tymth() returns associated Tymist .tyme.
+            tock is injected initial tock value
+            states is list of State namedtuples (tyme, context, feed, count)
+            opts is dict of injected optional additional parameters
     """
-    tyme = tymist.tyme
+    tyme = tymth()
     count = 0
     states = states if states is not None else []
 
     try:
         # enter context
-        states.append(State(tyme=tymist.tyme, context="enter", feed=tyme, count=count))
+        states.append(State(tyme=tymth(), context="enter", feed=tyme, count=count))
         while (True):  # recur context
             tyme = (yield (tock))  # yields tock then waits for next send
             count += 1
-            states.append(State(tyme=tymist.tyme, context="recur", feed=tyme, count=count))
+            states.append(State(tyme=tymth(), context="recur", feed=tyme, count=count))
             if count > 3:
                 break  # normal exit
 
     except GeneratorExit:  # close context, forced exit due to .close
         count += 1
-        states.append(State(tyme=tymist.tyme, context='close', feed=None, count=count))
+        states.append(State(tyme=tymth(), context='close', feed=None, count=count))
 
     except Exception as ex:  # abort context, forced exit due to uncaught exception
         count += 1
-        states.append(State(tyme=tymist.tyme, context='abort', feed=ex.args[0], count=count))
+        states.append(State(tyme=tymth(), context='abort', feed=ex.args[0], count=count))
         raise ex
 
     finally:  # exit context,  unforced exit due to normal exit of try
         count += 1
-        states.append(State(tyme=tymist.tyme, context='exit', feed=None, count=count))
+        states.append(State(tyme=tymth(), context='exit', feed=None, count=count))
 
     return (True)  # return value of yield from, or yield ex.value of StopIteration
